==> essential_node_protection-1.0.0.tar.gz: essential_node_protection/src/NodeAccessControlHandler.php <==
<?php

namespace Drupal\essential_node_protection;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityMalformedException;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\node\NodeAccessControlHandler as OriginalNodeAccessControlHandler;
use Drupal\path_alias\AliasManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the access control handler for the node entity type.
 */
class NodeAccessControlHandler extends OriginalNodeAccessControlHandler {

  /**
   * Configuration Factory.
   *
   * @var ConfigFactory
   */
  protected $configFactory;

  /**
   * @var AliasManager
   */
  protected $pathAliasManager;

  /**
   * @param ContainerInterface $container
   * @param EntityTypeInterface $entity_type
   * @return NodeAccessControlHandler|OriginalNodeAccessControlHandler
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    $instance =  parent::createInstance(
      $container,
      $entity_type
    );
    $instance->configFactory = $container->get('config.factory');
    $instance->pathAliasManager = $container->get('path_alias.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function access(EntityInterface $entity, $operation, AccountInterface $account = NULL, $return_as_object = FALSE) {
    if ($operation === 'delete' && $this->isEssential($entity)) {
      $result = AccessResult::forbidden('Node is essential and therefore cannot be deleted.');
      return $return_as_object ? $result : $result->isAllowed();
    }

    return parent::access($entity, $operation, $account, $return_as_object);
  }

  /**
   * @param EntityInterface $entity
   *
   * @return bool
   *
   * @throws EntityMalformedException
   */
  protected function isEssential(EntityInterface $entity) {
    $module_config = $this->getModuleConfig()->get('site_settings');
    $site_config = $this->configFactory->get('system.site')->get('page');

    $path_alias = $entity->toUrl()->toString();
    $system_path = $this->pathAliasManager->getPathByAlias($path_alias);

    $match = array_search($path_alias, $site_config) ?? array_search($system_path, $site_config);

    return $match && $module_config[$match] === 1;
  }

  private function getModuleConfig() {
    return $this->configFactory->get('essential_node_protection.settings');
  }

}

==> essential_node_protection-1.0.1.tar.gz: essential_node_protection/src/NodeAccessControlHandler.php <==
<?php

namespace Drupal\essential_node_protection;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityMalformedException;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\node\NodeAccessControlHandler as OriginalNodeAccessControlHandler;
use Drupal\path_alias\AliasManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the access control handler for the node entity type.
 */
class NodeAccessControlHandler extends OriginalNodeAccessControlHandler {

  /**
   * Configuration Factory.
   *
   * @var ConfigFactory
   */
  protected $configFactory;

  /**
   * @var AliasManager
   */
  protected $pathAliasManager;

  /**
   * @param ContainerInterface $container
   * @param EntityTypeInterface $entity_type
   * @return NodeAccessControlHandler|OriginalNodeAccessControlHandler
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    $instance =  parent::createInstance(
      $container,
      $entity_type
    );
    $instance->configFactory = $container->get('config.factory');
    $instance->pathAliasManager = $container->get('path_alias.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function access(EntityInterface $entity, $operation, AccountInterface $account = NULL, $return_as_object = FALSE) {
    if ($operation === 'delete' && $this->isEssential($entity)) {
      $result = AccessResult::forbidden('Node is essential and therefore cannot be deleted.');
      return $return_as_object ? $result : $result->isAllowed();
    }

    return parent::access($entity, $operation, $account, $return_as_object);
  }

  /**
   * @param EntityInterface $entity
   *
   * @return bool
   *
   * @throws EntityMalformedException
   */
  protected function isEssential(EntityInterface $entity) {
    $module_config = $this->getModuleConfig()->get('site_settings');
    $site_config = $this->configFactory->get('system.site')->get('page');

    $path_alias = $entity->toUrl()->toString();
    $system_path = $this->pathAliasManager->getPathByAlias($path_alias);

    $match = array_search($system_path, $site_config);

    // If there is a match and the protection for that match is enabled.
    return $match && $module_config[$match] === 1;
  }

  private function getModuleConfig() {
    return $this->configFactory->get('essential_node_protection.settings');
  }

}
